@@ -1103,7 +1103,6 @@ runscript(int argc, char **argv)
 	char *save = NULL;
 	char pidstr[10];
 	size_t l = 0, ll;
-	const char *file;
 	struct stat stbuf;
 
 	/* Show help if insufficient args */
@@ -1346,7 +1345,7 @@ runscript(int argc, char **argv)
 					    strerror(errno));
 				unhotplug();
 			} else
-				svc_exec(optarg, NULL);
+				retval = svc_exec(optarg, NULL);
 
 			/* We should ensure this list is empty after
 			 * an action is done */
